:orphan:

Welcome to Kivy
===============

Welcome to Kivy's documentation. Kivy is an open source software library for rapid
development of applications equipped with novel user interfaces, such as
multi-touch apps.

You are probably wondering why you'd be interested in using Kivy. There is
a document outlining our :ref:`philosophy` that we encourage you to read.

We recommend that you get started with :ref:`installation` and then head over to
the :ref:`quickstart` document. Besides the quickstart, there is also a more
detailed :ref:`architecture`.

If you want to contribute to Kivy, make sure to read :ref:`contributing`. If your
concern isn't addressed in the documentation, feel free to :ref:`contact`.

.. include:: contents.rst.inc


Appendix
========

The appendix contains licensing information and an enumeration of all the
different module, class, function and variable names available in Kivy.

License
-------

Kivy is released under the terms of the GNU LGPL Version 3.
You should have received a copy of the LGPL alongside your Kivy
distribution. See the file COPYING in the Kivy root folder.
An online version of the license can be found at
http://www.gnu.org/licenses/lgpl-3.0.txt

In a nutshell the license allows you to use Kivy in your own projects,
regardless if they are open source, closed source, commercial or free.
The one thing the license does enforce is that if you make changes to the
Kivy sourcecode **itself**, you have to share those changes with us.
For a more thorough legal explanation of the terms and conditions, please
refer to the documents listed above.

For a list of authors, please see the file AUTHORS that accompanies the
Kivy source code distribution (next to COPYING).


Kivy -- Copyright 2011, The Kivy Authors. All rights reserved.

